@@ -17,17 +17,11 @@ inst="$deps/install"
 
 export deps inst
 
+osmo-clean-workspace.sh
+
 mkdir -p "$deps"
-rm -rf "$inst"
 
-cd "$deps"
-
-# Get libosmocore for verify_value_string_arrays_are_terminated.py
-osmo-deps.sh libosmocore
-
-cd "$base"
-
-"$deps"/libosmocore/contrib/verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
+verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
 
 # generic project build function, usage:
 # build "PROJECT-NAME" "CONFIGURE OPTIONS"
@@ -41,11 +35,10 @@ build_bts() {
     set -x
 
     cd $deps
-    osmo-deps.sh openbsc
-    conf_flags="--with-openbsc=$deps/openbsc/openbsc/include"
+    osmo-deps.sh libosmocore
     cd $base
     shift
-    conf_flags="$conf_flags $*"
+    conf_flags="$*"
     autoreconf --install --force
     ./configure $conf_flags
     $MAKE $PARALLEL_MAKE
