@@ -73,7 +73,7 @@ static int oml_tx_failure_event_rep(struct gsm_abis_mo *mo, uint16_t cause_value
 	struct msgb *nmsg;
 	va_list ap;
 
-	LOGP(DOML, LOGL_NOTICE, "Reporting FAILURE to BSC: ");
+	LOGP(DOML, LOGL_NOTICE, "Sending %s to BSC: ", get_value_string(abis_mm_event_cause_names, cause_value));
 	va_start(ap, fmt);
 	osmo_vlogp(DOML, LOGL_NOTICE, __FILE__, __LINE__, 1, fmt, ap);
 	nmsg = abis_nm_fail_evt_vrep(NM_EVT_PROC_FAIL, NM_SEVER_CRITICAL,
@@ -214,14 +214,23 @@ static inline int handle_attrs_trx(uint8_t *out, struct gsm_bts_trx *trx, const
 		return -ENOMEM;
 
 	for (i = 0; i < attr_len; i++) {
+		bool processed = false;
 		switch (attr[i]) {
 		case NM_ATT_SW_CONFIG:
-			add_trx_attr(attr_buf, trx);
+			if (trx) {
+				add_trx_attr(attr_buf, trx);
+				processed = true;
+			} else
+				LOGP(DOML, LOGL_ERROR, "O&M Get Attributes [%u], %s is unhandled due to missing TRX.\n",
+				     i, get_value_string(abis_nm_att_names, attr[i]));
 			break;
 		default:
 			LOGP(DOML, LOGL_ERROR, "O&M Get Attributes [%u], %s is unsupported by TRX.\n", i,
 			     get_value_string(abis_nm_att_names, attr[i]));
-			out[attr_out_index] = attr[i]; /* assemble values of supported attributes and list of unsupported ones */
+		}
+		/* assemble values of supported attributes and list of unsupported ones */
+		if (!processed) {
+			out[attr_out_index] = attr[i];
 			attr_out_index++;
 		}
 	}
