@@ -711,8 +711,9 @@ DEFUN(cfg_trx_phy, cfg_trx_phy_cmd,
 
 static void net_dump_nmstate(struct vty *vty, struct gsm_nm_state *nms)
 {
-	vty_out(vty,"Oper '%s', Admin %u, Avail '%s'%s",
-		abis_nm_opstate_name(nms->operational), nms->administrative,
+	vty_out(vty,"Oper '%s', Admin '%s', Avail '%s'%s",
+		abis_nm_opstate_name(nms->operational),
+		get_value_string(abis_nm_adm_state_names, nms->administrative),
 		abis_nm_avail_name(nms->availability), VTY_NEWLINE);
 }
 
@@ -730,6 +731,7 @@ static unsigned int llist_length(struct llist_head *list)
 static void bts_dump_vty(struct vty *vty, struct gsm_bts *bts)
 {
 	struct gsm_bts_role_bts *btsb = bts->role;
+	struct gsm_bts_trx *trx;
 
 	vty_out(vty, "BTS %u is of %s type in band %s, has CI %u LAC %u, "
 		"BSIC %u and %u TRX%s",
@@ -762,24 +764,22 @@ static void bts_dump_vty(struct vty *vty, struct gsm_bts *bts)
 		VTY_NEWLINE);
 	vty_out(vty, "  CBCH backlog queue length: %u%s",
 		llist_length(&btsb->smscb_state.queue), VTY_NEWLINE);
-#if 0
-	vty_out(vty, "  Paging: %u pending requests, %u free slots%s",
-		paging_pending_requests_nr(bts),
-		bts->paging.available_slots, VTY_NEWLINE);
-	if (is_ipaccess_bts(bts)) {
-		vty_out(vty, "  OML Link state: %s.%s",
-			bts->oml_link ? "connected" : "disconnected", VTY_NEWLINE);
-	} else {
-		vty_out(vty, "  E1 Signalling Link:%s", VTY_NEWLINE);
-		e1isl_dump_vty(vty, bts->oml_link);
-	}
+	vty_out(vty, "  Paging: queue length %d, buffer space %d%s",
+		paging_queue_length(btsb->paging_state), paging_buffer_space(btsb->paging_state),
+		VTY_NEWLINE);
+	vty_out(vty, "  OML Link state: %s.%s",
+		bts->oml_link ? "connected" : "disconnected", VTY_NEWLINE);
 
-	/* FIXME: chan_desc */
-	memset(&pl, 0, sizeof(pl));
-	bts_chan_load(&pl, bts);
-	vty_out(vty, "  Current Channel Load:%s", VTY_NEWLINE);
-	dump_pchan_load_vty(vty, "    ", &pl);
-#endif
+	llist_for_each_entry(trx, &bts->trx_list, list) {
+		struct phy_instance *pinst = trx_phy_instance(trx);
+		vty_out(vty, "  TRX %u%s", trx->nr, VTY_NEWLINE);
+		if (pinst) {
+			vty_out(vty, "    phy %d %s", pinst->num, pinst->version);
+			if (pinst->description)
+				vty_out(vty, " (%s)", pinst->description);
+			vty_out(vty, "%s", VTY_NEWLINE);
+		}
+	}
 }
 
 
